from setuptools import setup, find_packages

setup(
    name="APKnife",
    version="1.0.4",
    description="APKnife is an advanced tool for APK analysis, modification, and security auditing. Whether you're a security researcher, penetration tester, or Android developer, APKnife provides powerful features for reverse engineering, decompiling, modifying, and analyzing APK files.",
    author="Mr_nightmare",
    author_email="hmjany18@gmail.com",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/elrashedy1992/APKnife",
    packages=find_packages(),
    python_requires=">=3.6",
    install_requires=[
        "alembic==1.14.1",
        "androguard==4.1.3",
        "apkInspector==1.3.2",
        "asn1crypto==1.5.1",
        "asttokens==3.0.0",
        "banal==1.0.6",
        "certifi==2025.1.31",
        "cffi==1.17.1",
        "charset-normalizer==3.4.1",
        "click==8.1.8",
        "colorama==0.4.6",
        "contourpy==1.3.1",
        "cryptography==44.0.2",
        "cycler==0.12.1",
        "dataset==1.6.2",
        "decorator==5.2.1",
        "executing==2.2.0",
        "fonttools==4.56.0",
        "frida==16.6.6",
        "future==1.0.0",
        "greenlet==3.1.1",
        "idna==3.10",
        "ipython==9.0.1",
        "ipython_pygments_lexers==1.1.1",
        "jedi==0.19.2",
        "kiwisolver==1.4.8",
        "loguru==0.7.3",
        "lxml==5.3.1",
        "Mako==1.3.9",
        "MarkupSafe==3.0.2",
        "matplotlib==3.10.1",
        "matplotlib-inline==0.1.7",
        "mutf8==1.0.6",
        "networkx==3.4.2",
        "numpy==2.2.3",
        "packaging==24.2",
        "parso==0.8.4",
        "pexpect==4.9.0",
        "pillow==11.1.0",
        "prompt_toolkit==3.0.50",
        "ptyprocess==0.7.0",
        "pure_eval==0.2.3",
        "pycparser==2.22",
        "pydot==3.0.4",
        "Pygments==2.19.1",
        "pyparsing==3.2.1",
        "python-dateutil==2.9.0.post0",
        "PyYAML==6.0.2",
        "requests==2.32.3",
        "setuptools==75.8.2",
        "six==1.17.0",
        "SQLAlchemy==1.4.54",
        "stack-data==0.6.3",
        "tqdm==4.67.1",
        "traitlets==5.14.3",
        "typing_extensions==4.12.2",
        "urllib3==2.3.0",
        "wcwidth==0.2.13",
        "wheel==0.45.1"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    project_urls={
        "Homepage": "https://github.com/elrashedy1992/APKnife",
        "Documentation": "https://github.com/elrashedy1992/APKnife/wiki",
        "Source": "https://github.com/elrashedy1992/APKnife",
    },
)
